@@ -188,7 +188,7 @@ our \$specialNodeHash = {
     samlIDPMetaDataNodes => [qw(samlIDPMetaDataXML samlIDPMetaDataExportedAttributes samlIDPMetaDataOptions)],
     samlSPMetaDataNodes  => [qw(samlSPMetaDataXML samlSPMetaDataExportedAttributes samlSPMetaDataOptions samlSPMetaDataMacros)],
     oidcOPMetaDataNodes  => [qw(oidcOPMetaDataJSON oidcOPMetaDataJWKS oidcOPMetaDataOptions oidcOPMetaDataExportedVars)],
-    oidcRPMetaDataNodes  => [qw(oidcRPMetaDataOptions oidcRPMetaDataExportedVars oidcRPMetaDataOptionsExtraClaims oidcRPMetaDataMacros)],
+    oidcRPMetaDataNodes  => [qw(oidcRPMetaDataOptions oidcRPMetaDataExportedVars oidcRPMetaDataOptionsExtraClaims oidcRPMetaDataMacros oidcRPMetaDataScopeRules)],
     casSrvMetaDataNodes  => [qw(casSrvMetaDataOptions casSrvMetaDataExportedVars)],
     casAppMetaDataNodes  => [qw(casAppMetaDataOptions casAppMetaDataExportedVars casAppMetaDataMacros)],
 };
@@ -207,7 +207,8 @@ EOF
     foreach (@simpleHashKeys) {
         $ra->add($_);
     }
-    print F "our \$simpleHashKeys = '" . $ra->as_string . "';\n"
+    print F "our \$simpleHashKeys = '"
+      . $ra->as_string . "';\n"
       . "our \$specialNodeKeys = '${ignoreKeys}s';\n";
     foreach ( sort keys %cnodesRe ) {
         print F "our \$${_}Keys = '$cnodesRe{$_}';\n";
@@ -467,7 +468,7 @@ sub buildPortalConstants() {
 
     printf STDERR $format, $self->portalConstantsFile;
     open( F, '>', $self->portalConstantsFile ) or die($!);
-    my $urire = $RE{URI}{HTTP}{ -scheme=>qr/https?/ }{-keep};
+    my $urire = $RE{URI}{HTTP}{ -scheme => qr/https?/ }{-keep};
     $urire =~ s/([\$\@])/\\$1/g;
     my $content = <<EOF;
 # This file is generated by $module. Don't modify it by hand
@@ -596,7 +597,7 @@ sub scanTree {
         # Subnode
         elsif ( ref($leaf) ) {
             $jleaf->{title} = $jleaf->{id} = $leaf->{title};
-            $jleaf->{type} = $leaf->{form} if ( $leaf->{form} );
+            $jleaf->{type}  = $leaf->{form} if ( $leaf->{form} );
             if ( $leaf->{title} =~ /^((?:oidc|saml|cas)Service)MetaData$/ ) {
                 no strict 'refs';
                 my @tmp = $self->scanLeaf( $leaf->{nodes} );
@@ -677,6 +678,7 @@ sub scanTree {
                     my $type = $attr->{type};
                     $type =~ s/Container//;
                     foreach my $k ( sort keys( %{ $attr->{default} } ) ) {
+
                         # Special handling for oidcAttribute
                         my $default = $attr->{default}->{$k};
                         if ( $attr->{type} eq 'oidcAttributeContainer' ) {
@@ -703,9 +705,9 @@ sub scanTree {
                 push @cnodesKeys, $leaf;
             }
 
-            # issue 2439
-            # FIXME: in future versions, oidcOPMetaDataJSON and samlIDPMetaDataXML shoud
-            # behave the same
+    # issue 2439
+    # FIXME: in future versions, oidcOPMetaDataJSON and samlIDPMetaDataXML shoud
+    # behave the same
             if ( $leaf =~ /^oidcOPMetaData(?:JSON|JWKS)$/ ) {
                 push @simpleHashKeys, $leaf;
             }
@@ -1006,7 +1008,7 @@ see L<Lemonldap::NG::Manager::Conf::Parser> before.
 =head1 DOWNLOAD
 
 Lemonldap::NG is available at
-L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
+L<https://lemonldap-ng.org/download>
 
 =head1 COPYRIGHT AND LICENSE
 
